@@ -4,6 +4,7 @@ from sqlalchemy import Column
 from sqlalchemy import event
 from sqlalchemy import ForeignKey
 from sqlalchemy import Index
+from sqlalchemy import inspect
 from sqlalchemy import Integer
 from sqlalchemy import MetaData
 from sqlalchemy import Numeric
@@ -12,7 +13,6 @@ from sqlalchemy import Table
 from sqlalchemy import Text
 from sqlalchemy import text
 from sqlalchemy import UniqueConstraint
-from sqlalchemy.engine.reflection import Inspector
 
 from alembic import autogenerate
 from alembic import util
@@ -42,6 +42,8 @@ def _default_include_object(obj, name, type_, reflected, compare_to):
 
 _default_object_filters = _default_include_object
 
+_default_name_filters = None
+
 
 class ModelOne(object):
     __requires__ = ("unique_constraint_reflection",)
@@ -186,12 +188,8 @@ class _ComparesFKs(object):
 
         eq_([elem.column.name for elem in diff[1].elements], target_columns)
         if conditional_name is not None:
-            if config.requirements.no_fk_names.enabled:
-                eq_(diff[1].name, None)
-            elif conditional_name == "servergenerated":
-                fks = Inspector.from_engine(self.bind).get_foreign_keys(
-                    source_table
-                )
+            if conditional_name == "servergenerated":
+                fks = inspect(self.bind).get_foreign_keys(source_table)
                 server_fk_name = fks[0]["name"]
                 eq_(diff[1].name, server_fk_name)
             else:
@@ -239,6 +237,7 @@ class AutogenTest(_ComparesFKs):
             "alembic_module_prefix": "op.",
             "sqlalchemy_module_prefix": "sa.",
             "include_object": _default_object_filters,
+            "include_name": _default_name_filters,
         }
         if self.configure_opts:
             ctx_opts.update(self.configure_opts)
@@ -251,11 +250,15 @@ class AutogenTest(_ComparesFKs):
     def tearDown(self):
         self.conn.close()
 
-    def _update_context(self, object_filters=None, include_schemas=None):
+    def _update_context(
+        self, object_filters=None, name_filters=None, include_schemas=None
+    ):
         if include_schemas is not None:
             self.autogen_context.opts["include_schemas"] = include_schemas
         if object_filters is not None:
             self.autogen_context._object_filters = [object_filters]
+        if name_filters is not None:
+            self.autogen_context._name_filters = [name_filters]
         return self.autogen_context
 
 
@@ -267,38 +270,55 @@ class AutogenFixtureTest(_ComparesFKs):
         include_schemas=False,
         opts=None,
         object_filters=_default_object_filters,
+        name_filters=_default_name_filters,
         return_ops=False,
+        max_identifier_length=None,
     ):
-        self.metadata, model_metadata = m1, m2
-        for m in util.to_list(self.metadata):
-            m.create_all(self.bind)
 
-        with self.bind.connect() as conn:
-            ctx_opts = {
-                "compare_type": True,
-                "compare_server_default": True,
-                "target_metadata": model_metadata,
-                "upgrade_token": "upgrades",
-                "downgrade_token": "downgrades",
-                "alembic_module_prefix": "op.",
-                "sqlalchemy_module_prefix": "sa.",
-                "include_object": object_filters,
-                "include_schemas": include_schemas,
-            }
-            if opts:
-                ctx_opts.update(opts)
-            self.context = context = MigrationContext.configure(
-                connection=conn, opts=ctx_opts
-            )
+        if max_identifier_length:
+            dialect = self.bind.dialect
+            existing_length = dialect.max_identifier_length
+            dialect.max_identifier_length = (
+                dialect._user_defined_max_identifier_length
+            ) = max_identifier_length
+        try:
+            self._alembic_metadata, model_metadata = m1, m2
+            for m in util.to_list(self._alembic_metadata):
+                m.create_all(self.bind)
 
-            autogen_context = api.AutogenContext(context, model_metadata)
-            uo = ops.UpgradeOps(ops=[])
-            autogenerate._produce_net_changes(autogen_context, uo)
+            with self.bind.connect() as conn:
+                ctx_opts = {
+                    "compare_type": True,
+                    "compare_server_default": True,
+                    "target_metadata": model_metadata,
+                    "upgrade_token": "upgrades",
+                    "downgrade_token": "downgrades",
+                    "alembic_module_prefix": "op.",
+                    "sqlalchemy_module_prefix": "sa.",
+                    "include_object": object_filters,
+                    "include_name": name_filters,
+                    "include_schemas": include_schemas,
+                }
+                if opts:
+                    ctx_opts.update(opts)
+                self.context = context = MigrationContext.configure(
+                    connection=conn, opts=ctx_opts
+                )
 
-            if return_ops:
-                return uo
-            else:
-                return uo.as_diffs()
+                autogen_context = api.AutogenContext(context, model_metadata)
+                uo = ops.UpgradeOps(ops=[])
+                autogenerate._produce_net_changes(autogen_context, uo)
+
+                if return_ops:
+                    return uo
+                else:
+                    return uo.as_diffs()
+        finally:
+            if max_identifier_length:
+                dialect = self.bind.dialect
+                dialect.max_identifier_length = (
+                    dialect._user_defined_max_identifier_length
+                ) = existing_length
 
     reports_unnamed_constraints = False
 
@@ -307,7 +327,7 @@ class AutogenFixtureTest(_ComparesFKs):
         self.bind = config.db
 
     def tearDown(self):
-        if hasattr(self, "metadata"):
-            for m in util.to_list(self.metadata):
+        if hasattr(self, "_alembic_metadata"):
+            for m in util.to_list(self._alembic_metadata):
                 m.drop_all(self.bind)
         clear_staging_env()
